==> haskell-hashable-1.3.3.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hashable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hashable
version:              1.3.3.0
visibility:           public
id:                   hashable-1.3.3.0-23uoxU4x6MLFe9vf4ULvQk
key:                  hashable-1.3.3.0-23uoxU4x6MLFe9vf4ULvQk
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Milan Straka <fox@ucw.cz>
    Johan Tibell <johan.tibell@gmail.com>

stability:            Provisional
homepage:             http://github.com/haskell-unordered-containers/hashable
synopsis:             A class for types that can be converted to a hash value
description:
    This package defines a class, '\''Hashable'\'', for types that
    can be converted to a hash value.  This class
    exists for the benefit of hashing-based data
    structures.  The package provides instances for
    basic types and a way to combine hash values.

category:             Data
abi:                  591724614ca77995eee19de944061f59
exposed:              True
exposed-modules:
    Data.Hashable Data.Hashable.Generic Data.Hashable.Lifted

hidden-modules:       Data.Hashable.Class Data.Hashable.Generic.Instances
import-dirs:          /usr/lib/ghc-9.0.1/site-local/hashable-1.3.3.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hashable-1.3.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/hashable-1.3.3.0
hs-libraries:         HShashable-1.3.3.0-23uoxU4x6MLFe9vf4ULvQk
depends:
    base-4.15.0.0 bytestring-0.10.12.1 deepseq-1.4.5.0 ghc-bignum-1.0
    ghc-prim-0.7.0 text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-hashable/html/hashable.haddock
haddock-html:         /usr/share/doc/haskell-hashable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hashable-1.3.3.0-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hashable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hashable
version:              1.3.3.0
visibility:           public
id:                   hashable-1.3.3.0-42gRc2xLctC1JaYfPjkrlX
key:                  hashable-1.3.3.0-42gRc2xLctC1JaYfPjkrlX
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Milan Straka <fox@ucw.cz>
    Johan Tibell <johan.tibell@gmail.com>

stability:            Provisional
homepage:             http://github.com/haskell-unordered-containers/hashable
synopsis:             A class for types that can be converted to a hash value
description:
    This package defines a class, '\''Hashable'\'', for types that
    can be converted to a hash value.  This class
    exists for the benefit of hashing-based data
    structures.  The package provides instances for
    basic types and a way to combine hash values.

category:             Data
abi:                  b3b0d53a51441b276443a61ff14bd8ca
exposed:              True
exposed-modules:
    Data.Hashable Data.Hashable.Generic Data.Hashable.Lifted

hidden-modules:       Data.Hashable.Class Data.Hashable.Generic.Instances
import-dirs:          /usr/lib/ghc-9.0.1/site-local/hashable-1.3.3.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hashable-1.3.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/hashable-1.3.3.0
hs-libraries:         HShashable-1.3.3.0-42gRc2xLctC1JaYfPjkrlX
depends:
    base-4.15.0.0 bytestring-0.10.12.1 deepseq-1.4.5.0 ghc-bignum-1.0
    ghc-prim-0.7.0 text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-hashable/html/hashable.haddock
haddock-html:         /usr/share/doc/haskell-hashable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
